{
    **schema_registry.get("question_base"),
    "ébauches": {
        "required": True,
        "type": "dict",
        "empty": False,
        "valuesrules": {"type": "string", "nullable": True},
    },
    "tests": {
        "required": True,
        "type": "list",
        "empty": False,
        "schema": {
            "required": True,
            "type": "dict",
            "schema": "test_prog",
        },
    },
}



{
    "nom": {"required": False, "type": "string"},
    "sortie": {
        "required": False,
        "type": ["string", "integer"],
        "nullable": False,
    },
    "rétroactions": {
        "required": False,
        "type": "dict",
        "schema": "rétroactions",
    },
    "caché": {"required": False, "type": "boolean"},
}



{
    "type": {"required": True, "type": "string", "regex": "(?i)^(prog|sys|bd|vcs)$"},
    "niveau": {"required": False, "type": "string"},
    "titre": {"required": False, "type": "string"},
    "objectif": {"required": False, "type": "string"},
    "description": {"required": False, "type": "string"},
    "énoncé": {
        "required": False,
        "type": ["string", "list"],
        "schema": {
            "required": True,
            "empty": False,
            "type": "dict",
            "schema": {
                "titre": {"required": False, "type": "string"},
                "texte": {"required": True, "type": "string"},
            },
        },
    },
    "auteur": {"required": False, "type": "string"},
    "licence": {"required": False, "type": "string"},
    "rétroactions": {"required": False, "type": "dict", "schema": "rétroactions"},
    "ttl": {"required": False, "type": "integer"},
}



{
    **schema_registry.get("test_base"),
    "entrée": {
        "required": False,
        "type": ["string", "integer"],
        "nullable": False,
    },
    "params": {
        "required": False,
        "type": ["string", "integer"],
        "nullable": False,
    },
}



{
    **schema_registry.get("question_base"),
    "image": {
        "required": True,
        "type": "string",
        "empty": False,
        "nullable": True,
    },
    "tests": {
        "excludes": "réponse",
        "required": True,
        "type": "list",
        "empty": False,
        "schema": {
            "required": True,
            "type": "dict",
            "schema": "test_sys",
        },
    },
    "réponse": {
        "excludes": "tests",
        "required": True,
        "type": "string",
        "empty": False,
        "nullable": False,
    },
    "utilisateur": {
        "required": False,
        "type": "string",
        "regex": "^[a-z][-a-z0-9_]*$",
        "nullable": False,
    },
    "init": {
        "required": False,
        "type": "string",
        "empty": False,
        "nullable": False,
    },
    "commande": {
        "required": False,
        "type": "string",
        "empty": False,
        "nullable": False,
    },
}



{
    **schema_registry.get("test_base"),
    "validation": {
        "required": True,
        "type": "string",
        "empty": False,
        "nullable": False,
    },
    "utilisateur": {
        "required": False,
        "type": "string",
        "regex": "^[a-z][-a-z0-9_]*$",
        "nullable": False,
    },
}



from progression_qc.progression_qc import *
import progression_qc
import traceback
import urllib

if __name__ == "__main__":
    args = traiter_paramètres()

    if args.version:
        print(f"progression_qc version {progression_qc.__version__}")
        code_retour = 0
    else:
        try:
            infos_question = charger_question(args.fichier, get_readers())
            if not infos_question:
                resultats = {"erreurs": {args.fichier: "Format YAML invalide"}}
            else:
                resultats = valider_schema_yaml_infos_question(infos_question)
                resultats["infos_question"] = infos_question
            code_retour = déterminer_code_retour(resultats)
        except (urllib.error.HTTPError, urllib.error.URLError) as e:
            code_retour = 255
            if args.verbose:
                print(traceback.format_exc(), file=sys.stderr)
            resultats = {"erreurs": {args.fichier: e}}

        if not args.quiet:
            if args.json:
                afficher_résultats_json(resultats)
            else:
                afficher_résultats(resultats)

    exit(code_retour)
